pub enum ChecksumValidationError {
InvalidWidth {
algorithm: ChecksumAlgorithm,
expected_len: usize,
actual_len: usize,
},
InvalidAlphabet {
algorithm: ChecksumAlgorithm,
},
}Expand description
Describes why a checksum is not in its canonical wire form.
Variants
InvalidWidth
The checksum value does not have the exact width for its algorithm.
Fields

algorithm: ChecksumAlgorithmAlgorithm whose checksum width was required.
InvalidAlphabet
The checksum value contains a character outside lowercase hexadecimal.
Fields

algorithm: ChecksumAlgorithmAlgorithm whose checksum value was rejected.