pub enum ContentEvidence<'a> {
Bytes(&'a [u8]),
ContentRef(&'a ContentRef),
}Expand description
Available proof that a payload matches a committed content reference.
Variants
Bytes(&'a [u8])
Bytes that can be hashed with the committed reference’s algorithm.
ContentRef(&'a ContentRef)
A reference carrying checksum evidence about its payload.