pub enum ContentRefKind {
BlobV1,
}Expand description
A supported content reference kind serialized as a string.
Variants
BlobV1
One immutable content object, addressed by its random content id.
Implementations