pub enum PageCursorError {
InvalidEncoding,
InvalidJson(String),
WrongKind {
expected: &'static str,
actual: String,
},
UnsupportedVersion {
expected: u8,
actual: u8,
},
}Expand description
Invalid opaque page cursor.
Variants
InvalidEncoding
The cursor was not hex-encoded JSON.
InvalidJson(String)
The cursor JSON did not match a supported cursor shape.
WrongKind
The cursor was valid, but for a different paginated endpoint.
Fields
UnsupportedVersion
The cursor format version is not supported by this build.