#[non_exhaustive]pub enum PutRetryErrorClassification {
CommitIdReuseConflict(Option<PutRetryReceipt>),
RebootstrapRequired,
Other,
}Expand description
Classification of an error encountered while verifying a retried PUT.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CommitIdReuseConflict(Option<PutRetryReceipt>)
The commit ID was already used. The receipt is included when available.
RebootstrapRequired
Retention removed the change record needed to verify the retry.
Other
Any error that does not have special handling during retry verification.