pub struct MoveOptions {
pub behavior: DestinationBehavior,
pub commit: CommitOptions,
pub expected_destination_inode_id: Option<InodeId>,
pub expected_destination_revision_no: Option<RevisionNo>,
}Expand description
Options for moving a path.
Fields
behavior: DestinationBehaviorCreate-only or replace-existing behavior for the destination.
commit: CommitOptionsActor, commit ID, and message.
expected_destination_inode_id: Option<InodeId>The inode that the destination must still reference when using Replace behavior.
expected_destination_revision_no: Option<RevisionNo>The revision that must still be current when using Replace behavior with
expected_destination_inode_id.
Implementations