pub struct UpdateAttributesOptions {
pub set: BTreeMap<AttributeKey, AttributeValue>,
pub remove: Vec<AttributeKey>,
pub commit: CommitOptions,
pub expected_inode_id: Option<InodeId>,
pub expected_attributes_revision_no: Option<AttributeRevisionNo>,
}Expand description
Options for writing and removing an inode’s attributes.
Fields
set: BTreeMap<AttributeKey, AttributeValue>The attributes to write, replacing values for matching keys and leaving other keys unchanged.
remove: Vec<AttributeKey>Keys to remove.
commit: CommitOptionsActor, commit ID, and message.
expected_inode_id: Option<InodeId>The inode that the path must still resolve to before the update.
expected_attributes_revision_no: Option<AttributeRevisionNo>With an inode precondition, the attribute revision that must still be current.
Implementations