pub struct EffectiveLimit(/* private fields */);Expand description
A validated page size selected from a caller request and a policy.
Implementations
Sourceimpl EffectiveLimit
impl EffectiveLimit
Sourcepub fn new(value: NonZeroU32) -> Self
pub fn new(value: NonZeroU32) -> Self
Creates an effective limit from a non-zero value.
Sourcepub fn as_usize(self) -> usize
pub fn as_usize(self) -> usize
Returns the page size as a usize for vector reservations and counters.
Sourcepub fn limit_plus_one(self) -> usize
pub fn limit_plus_one(self) -> usize
Returns the number of items an engine should try to read to detect a next page.