pub struct GrepPageCursor {
pub head_seq: ChangeSeq,
pub last_inode_id: InodeId,
pub last_byte_offset: u64,
pub fingerprint: u64,
}Expand description
A cursor that resumes content search after one (inode_id, byte_offset) position.
Fields
head_seq: ChangeSeqSequence the issuing page was evaluated at.
last_inode_id: InodeIdInode of the last candidate the issuing page finished scanning.
last_byte_offset: u64The last match offset, or u64::MAX when the file was fully scanned.
fingerprint: u64The fingerprint of the pattern, flags, and scope that issued the cursor.