pub struct Page<T, C> {
pub items: Vec<T>,
pub next_cursor: Option<C>,
}Expand description
A typed page result for internal runtime and core methods.
Fields
items: Vec<T>Returned items.
next_cursor: Option<C>Cursor for the next page, if another page is available.