#[non_exhaustive]pub enum DestinationPreconditionError {
PreconditionsRequireReplace {
field: &'static str,
},
RevisionRequiresInode {
revision_field: &'static str,
inode_field: &'static str,
},
}Expand description
Why a destination precondition is not a valid request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PreconditionsRequireReplace
A create-only operation supplied a replacement precondition.
RevisionRequiresInode
A revision precondition did not name the inode whose revision it checks.