pub enum PathEntryKind {
Directory {},
File {
revision_no: RevisionNo,
size_bytes: u64,
content_ref: ContentRef,
revision_committed_by: ActorId,
revision_committed_at_ms: u64,
},
}Expand description
Kind-specific metadata for a path entry.
Variants
Directory
A directory without a revision payload.
File
A file and its current revision summary.
Fields

revision_no: RevisionNoCurrent file revision number.

content_ref: ContentRefCurrent content reference.
Implementations
Sourceimpl PathEntryKind
impl PathEntryKind
Sourcepub const fn inode_kind(&self) -> InodeKind
pub const fn inode_kind(&self) -> InodeKind
Returns the stable inode classification represented by this payload.
Sourcepub const fn revision_committed_by(&self) -> Option<&ActorId>
pub const fn revision_committed_by(&self) -> Option<&ActorId>
Returns the actor responsible for the current file revision.
Directories return None.