RetainedReason

Enum RetainedReason 

#[non_exhaustive]
pub enum RetainedReason { Referenced, GraceWindow, NoProviderTimestamp, DegradedRoots, UnrecognizedKey, CheckpointNotReleasable, UploadSessionWindow, UploadSessionUndecided, ContentScanDeferred, }
The reason one candidate was retained, as the sweep site knows it. Each variant is the field of RetainedCandidates it counts into, where the reason itself is described.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Referenced



GraceWindow



NoProviderTimestamp



DegradedRoots



UnrecognizedKey



CheckpointNotReleasable



UploadSessionWindow



UploadSessionUndecided



ContentScanDeferred