pub struct Checkpoint {
pub namespace_id: NamespaceId,
pub checkpoint_id: CheckpointId,
pub owner: CheckpointOwnerSummary,
pub created_at_ms: u64,
pub expires_at_ms: Option<u64>,
pub captured_seq: ChangeSeq,
pub manifest_no: ManifestNo,
}Expand description
One checkpoint resource described by its durable record.
Fields
namespace_id: NamespaceIdNamespace that owns the checkpoint.
checkpoint_id: CheckpointIdDurable checkpoint id used to address the checkpoint for deletion.
owner: CheckpointOwnerSummaryWho owns the checkpoint, including the label carried by a user pin.
created_at_ms: u64Time the checkpoint record was created, in Unix milliseconds.
expires_at_ms: Option<u64>Expiry in Unix milliseconds; collection waits one further grace window.
captured_seq: ChangeSeqNamespace sequence captured by the checkpoint.
manifest_no: ManifestNoManifest pinned by the checkpoint.