pub struct CreateSnapshotRequest {
pub name: String,
pub ttl_ms: u64,
}Expand description
Request to create a snapshot.
Fields
name: StringA label that does not need to be unique.
ttl_ms: u64Snapshot lifetime from the current server time, in milliseconds.