pub struct DisableGrepIndexResponse {
pub namespace_id: NamespaceId,
pub was_enabled: bool,
}Expand description
Result of disabling the grep index on a namespace (admin plane).
Fields
namespace_id: NamespaceIdNamespace whose grep root was disabled.
was_enabled: boolFalse when the namespace had no enabled grep root.