pub struct GrepGcResponse {
pub namespace_id: NamespaceId,
pub deleted_segments: u64,
pub deleted_other_objects: u64,
pub namespace_reaped: bool,
pub retained_candidates: u64,
}Expand description
Result of one explicit grep index garbage-collection pass (maintenance API group).
Fields
namespace_id: NamespaceIdNamespace whose grep-owned keyspace was inspected.
deleted_segments: u64Unreferenced grep segments older than the minimum segment age.
deleted_other_objects: u64Other unreferenced grep objects deleted after the grace window.
namespace_reaped: boolWhether an absent or tombstoned namespace had extension state reaped.
retained_candidates: u64Referenced, young, or unrecognized candidates retained by the pass.