pub struct UploadContentClaim {
pub size_bytes: u64,
pub checksum: Checksum,
}Expand description
The size and checksum reported for a complete direct-upload payload.
Fields
size_bytes: u64Complete payload size in bytes.
checksum: ChecksumWhole-payload checksum in the algorithm required by this operation.