pub fn hex_encode_row_key_component(value: &str) -> StringExpand description
Encodes an arbitrary string so it can occupy one component of a durable row key.
See metadata segments.
pub fn hex_encode_row_key_component(value: &str) -> StringEncodes an arbitrary string so it can occupy one component of a durable row key.
See metadata segments.