pub fn decode_data_block(
stored: &[u8],
handle: &BlockHandle,
) -> Result<DecodedDataBlock, SstBlockCodecError>Expand description
Decodes one data block from exactly the bytes its handle names.
pub fn decode_data_block(
stored: &[u8],
handle: &BlockHandle,
) -> Result<DecodedDataBlock, SstBlockCodecError>Decodes one data block from exactly the bytes its handle names.