decode_data_block_rows

Function decode_data_block_rows 

pub fn decode_data_block_rows<R: DeserializeOwned>(
    stored: &[u8],
    handle: &BlockHandle,
) -> Result<DecodedDataBlock<R>, SstBlockCodecError>
Decodes one data block whose rows are R, for segment families whose row payload is not MetadataRow (gram index segments).