pub struct WalCommitDelta {
pub semantic_op_index: u32,
pub delta: WalDelta,
}Expand description
Associates a materialized WAL delta with the semantic operation that produced it.
See logical commits.
Fields
semantic_op_index: u32Zero-based request-operation position used to attribute one or more resulting deltas.
delta: WalDeltaReplay mutation produced for that semantic operation.