pub struct ManifestId(pub u64);Expand description
Monotonically increasing namespace manifest identity.
This is the durable file-set version identity for namespace manifests. Initial/fork manifests may be seeded from the current head sequence, but later manifest ids can advance for checkpoint metadata, compaction, or fork/index metadata without a new namespace commit.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ManifestId
impl Clone for ManifestId
Sourcefn clone(&self) -> ManifestId
fn clone(&self) -> ManifestId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ManifestId
Sourceimpl Debug for ManifestId
impl Debug for ManifestId
Sourceimpl<'de> Deserialize<'de> for ManifestId
impl<'de> Deserialize<'de> for ManifestId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ManifestId
impl Display for ManifestId
impl Eq for ManifestId
Sourceimpl From<u64> for ManifestId
impl From<u64> for ManifestId
Sourceimpl Hash for ManifestId
impl Hash for ManifestId
Sourceimpl Ord for ManifestId
impl Ord for ManifestId
Sourcefn cmp(&self, other: &ManifestId) -> Ordering
fn cmp(&self, other: &ManifestId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ManifestId
impl PartialEq for ManifestId
Sourceimpl PartialOrd for ManifestId
impl PartialOrd for ManifestId
Sourceimpl Serialize for ManifestId
impl Serialize for ManifestId
impl StructuralPartialEq for ManifestId