pub struct AttributesProjection {
pub attributes_revision_no: AttributeRevisionNo,
pub attributes_updated_by: Option<ActorRef>,
pub attributes_updated_at_ms: Option<u64>,
pub attributes: Attributes,
}Expand description
One inode’s structurally complete attribute projection.
Fields
attributes_revision_no: AttributeRevisionNoThe attribute revision this projection represents.
attributes_updated_by: Option<ActorRef>Actor responsible for the latest attribute update. This is None for
the initial empty state at revision 0.
attributes_updated_at_ms: Option<u64>Time of the latest attribute update, in Unix milliseconds. This is
None for the initial empty state at revision 0.
attributes: AttributesThe complete attribute map at attributes_revision_no.
An inode that has never had attributes written is at revision 0 with an empty map.