pub struct GrepGcResponse {
pub namespace_id: NamespaceId,
pub deleted_segments: u64,
pub deleted_other_objects: u64,
pub namespace_reaped: bool,
pub retained_candidates: u64,
pub namespace_degraded: bool,
pub next_cursor: Option<String>,
}Expand description
Result of one explicit grep-index garbage-collection pass (admin plane).
Fields
namespace_id: NamespaceIdNamespace whose grep-owned keyspace was inspected.
deleted_segments: u64Unreferenced grep segments deleted after the grace window.
deleted_other_objects: u64Other unreferenced grep objects deleted after the grace window.
namespace_reaped: boolWhether an absent or tombstoned namespace had extension state reaped.
retained_candidates: u64Young or concurrently revived candidates retained by the pass.
namespace_degraded: boolWhether unreadable namespace or grep state forced conservative retention.
next_cursor: Option<String>Present when the budget stopped the pass with keys left to examine.