pub struct ForkBasis {
pub manifest: ManifestRef,
pub source_checkpoint_id: CheckpointId,
}Expand description
Immutable fork provenance matched against the source checkpoint by GC.
Fields
manifest: ManifestRefSource manifest used as the target’s initial state. Its owner must
differ from the target namespace. manifest_head_seq is the target’s
initial sequence.
source_checkpoint_id: CheckpointIdSource checkpoint record pinning the basis for as long as the target lives.